#' @keywords internal
#' @section Acknowledgements:
#' Developed in the Dries Lab at Boston University. This work was supported by
#' the Dries Lab and the Boston University Undergraduate Research Opportunities
#' Program (UROP).
"_PACKAGE"

## usethis namespace: start
## usethis namespace: end
NULL
